Method: Sinatra::TestHelpers#app

Defined in:
lib/sinatra/test_helpers.rb

#appSinatra::Base

Returns a Rack::Lint-wrapped Sinatra app.

If no app has been configured, a new subclass of Sinatra::Base will be used and stored.

(Rack::Lint validates your application and the requests and responses according to the Rack spec.)

Returns:

  • (Sinatra::Base)


151
152
153
154
# File 'lib/sinatra/test_helpers.rb', line 151

def app
  @app ||= Class.new Sinatra::Base
  Rack::Lint.new @app
end