Method: Sinatra::Reloader::BaseMethods#inline_templates=
- Defined in:
- lib/sinatra/reloader.rb
#inline_templates=(file = nil) ⇒ Object
Does everything Sinatra::Base#inline_templates= does, but it also tells the Watcher::List for the Sinatra application to watch the inline templates in file or the file who made the call to this method.
302 303 304 305 306 |
# File 'lib/sinatra/reloader.rb', line 302 def inline_templates=(file = nil) file = (caller_files[1] || File.($0)) if file.nil? || file == true watch_element(file, :inline_templates) super end |